@@ -1,4 +1,4 @@
-# (c) 2020-2021 Michał Górny
+# (c) 2020-2022 Michał Górny
 # 2-clause BSD license
 
 """ Bugzilla support. """
@@ -53,9 +53,6 @@ class BugCategory(enum.Enum):
                 return cls.KEYWORDREQ
             elif component == 'Stabilization':
                 return cls.STABLEREQ
-        elif product == 'Gentoo Security':
-            if component in ('Vulnerabilities', 'Kernel'):
-                return cls.STABLEREQ
         return None
 
     @classmethod
@@ -71,8 +68,7 @@ class BugCategory(enum.Enum):
         if val == cls.KEYWORDREQ:
             return (['Gentoo Linux'], ['Keywording'])
         elif val == cls.STABLEREQ:
-            return (['Gentoo Linux', 'Gentoo Security'],
-                    ['Stabilization', 'Vulnerabilities', 'Kernel'])
+            return (['Gentoo Linux'], ['Stabilization'])
         else:
             assert False, f'Incorrect BugCategory: {val}'
 
@@ -272,11 +268,15 @@ class NattkaBugzilla(object):
             # are all dependencies satisfied?
             if not missing:
                 return bugs
+            # do not try to query >500 bugs to avoid exceeding max
+            # request length
+            if len(missing) > 500:
+                missing = set(list(missing)[:500])
             newbugs = self.find_bugs(missing)
             # verify that all bugs fetch, prevent dead loop
             assert all(x in newbugs for x in missing)
             # copy the dictionary to avoid modifying the original
-            # (technically, this only needs to be done but no harm
+            # (technically, this only needs to be done once but no harm
             #  in repeating)
             bugs = dict(bugs)
             bugs.update(newbugs)
